@@ -1,13 +1,13 @@
 /* Test file for mpfr_sec.
 
-Copyright 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
-Contributed by the Arenaire and Cacao projects, INRIA.
+Copyright 2005-2023 Free Software Foundation, Inc.
+Contributed by the AriC and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
 The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The GNU MPFR Library is distributed in the hope that it will be useful, but
@@ -16,12 +16,9 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
-
-#include <stdio.h>
-#include <stdlib.h>
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+https://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #include "mpfr-test.h"
 
@@ -38,7 +35,7 @@ check_specials (void)
   mpfr_init2 (y, 123L);
 
   mpfr_set_nan (x);
-  mpfr_sec (y, x, GMP_RNDN);
+  mpfr_sec (y, x, MPFR_RNDN);
   if (! mpfr_nan_p (y))
     {
       printf ("Error: sec(NaN) != NaN\n");
@@ -46,7 +43,7 @@ check_specials (void)
     }
 
   mpfr_set_inf (x, 1);
-  mpfr_sec (y, x, GMP_RNDN);
+  mpfr_sec (y, x, MPFR_RNDN);
   if (! mpfr_nan_p (y))
     {
       printf ("Error: sec(Inf) != NaN\n");
@@ -54,7 +51,7 @@ check_specials (void)
     }
 
   mpfr_set_inf (x, -1);
-  mpfr_sec (y, x, GMP_RNDN);
+  mpfr_sec (y, x, MPFR_RNDN);
   if (! mpfr_nan_p (y))
     {
       printf ("Error: sec(-Inf) != NaN\n");
@@ -62,15 +59,15 @@ check_specials (void)
     }
 
   /* sec(+/-0) = 1 */
-  mpfr_set_ui (x, 0, GMP_RNDN);
-  mpfr_sec (y, x, GMP_RNDN);
+  mpfr_set_ui (x, 0, MPFR_RNDN);
+  mpfr_sec (y, x, MPFR_RNDN);
   if (mpfr_cmp_ui (y, 1))
     {
       printf ("Error: sec(+0) != 1\n");
       exit (1);
     }
-  mpfr_neg (x, x, GMP_RNDN);
-  mpfr_sec (y, x, GMP_RNDN);
+  mpfr_neg (x, x, MPFR_RNDN);
+  mpfr_sec (y, x, MPFR_RNDN);
   if (mpfr_cmp_ui (y, 1))
     {
       printf ("Error: sec(-0) != 1\n");
@@ -86,7 +83,7 @@ overflowed_sec0 (void)
 {
   mpfr_t x, y;
   int emax, i, inex, rnd, err = 0;
-  mp_exp_t old_emax;
+  mpfr_exp_t old_emax;
 
   old_emax = mpfr_get_emax ();
 
@@ -95,37 +92,38 @@ overflowed_sec0 (void)
 
   for (emax = -1; emax <= 0; emax++)
     {
-      mpfr_set_ui_2exp (y, 1, emax, GMP_RNDN);
+      mpfr_set_ui_2exp (y, 1, emax, MPFR_RNDN);
       mpfr_nextbelow (y);
       set_emax (emax);  /* 1 is not representable. */
       for (i = -1; i <= 1; i++)
-        RND_LOOP (rnd)
+        RND_LOOP_NO_RNDF (rnd)
           {
-            mpfr_set_si_2exp (x, i, -512 * ABS (i), GMP_RNDN);
+            mpfr_set_si_2exp (x, i, -512 * ABS (i), MPFR_RNDN);
             mpfr_clear_flags ();
-            inex = mpfr_sec (x, x, (mp_rnd_t) rnd);
+            inex = mpfr_sec (x, x, (mpfr_rnd_t) rnd);
             if (! mpfr_overflow_p ())
               {
                 printf ("Error in overflowed_sec0 (i = %d, rnd = %s):\n"
                         "  The overflow flag is not set.\n",
-                        i, mpfr_print_rnd_mode ((mp_rnd_t) rnd));
+                        i, mpfr_print_rnd_mode ((mpfr_rnd_t) rnd));
                 err = 1;
               }
-            if (rnd == GMP_RNDZ || rnd == GMP_RNDD)
+            if (rnd == MPFR_RNDZ || rnd == MPFR_RNDD)
               {
                 if (inex >= 0)
                   {
                     printf ("Error in overflowed_sec0 (i = %d, rnd = %s):\n"
                             "  The inexact value must be negative.\n",
-                            i, mpfr_print_rnd_mode ((mp_rnd_t) rnd));
+                            i, mpfr_print_rnd_mode ((mpfr_rnd_t) rnd));
                     err = 1;
                   }
                 if (! mpfr_equal_p (x, y))
                   {
                     printf ("Error in overflowed_sec0 (i = %d, rnd = %s):\n"
-                            "  Got ", i, mpfr_print_rnd_mode ((mp_rnd_t) rnd));
-                    mpfr_print_binary (x);
-                    printf (" instead of 0.11111111E%d.\n", emax);
+                            "  Got        ", i,
+                            mpfr_print_rnd_mode ((mpfr_rnd_t) rnd));
+                    mpfr_dump (x);
+                    printf ("  instead of 0.11111111E%d.\n", emax);
                     err = 1;
                   }
               }
@@ -135,15 +133,16 @@ overflowed_sec0 (void)
                   {
                     printf ("Error in overflowed_sec0 (i = %d, rnd = %s):\n"
                             "  The inexact value must be positive.\n",
-                            i, mpfr_print_rnd_mode ((mp_rnd_t) rnd));
+                            i, mpfr_print_rnd_mode ((mpfr_rnd_t) rnd));
                     err = 1;
                   }
-                if (! (mpfr_inf_p (x) && MPFR_SIGN (x) > 0))
+                if (! (mpfr_inf_p (x) && MPFR_IS_POS (x)))
                   {
                     printf ("Error in overflowed_sec0 (i = %d, rnd = %s):\n"
-                            "  Got ", i, mpfr_print_rnd_mode ((mp_rnd_t) rnd));
-                    mpfr_print_binary (x);
-                    printf (" instead of +Inf.\n");
+                            "  Got        ", i,
+                            mpfr_print_rnd_mode ((mpfr_rnd_t) rnd));
+                    mpfr_dump (x);
+                    printf ("  instead of +Inf.\n");
                     err = 1;
                   }
               }
@@ -164,7 +163,7 @@ main (int argc, char *argv[])
 
   check_specials ();
 
-  test_generic (2, 200, 10);
+  test_generic (MPFR_PREC_MIN, 200, 10);
   overflowed_sec0 ();
 
   tests_end_mpfr ();
