@@ -1,37 +1,35 @@
 /* Test file for mpfr_set_f.
 
-Copyright 1999, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
-Contributed by the Arenaire and Cacao projects, INRIA.
+Copyright 1999, 2001-2023 Free Software Foundation, Inc.
+Contributed by the AriC and Caramba projects, INRIA.
 
-This file is part of the MPFR Library.
+This file is part of the GNU MPFR Library.
 
-The MPFR Library is free software; you can redistribute it and/or modify
+The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
-The MPFR Library is distributed in the hope that it will be useful, but
+The GNU MPFR Library is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <limits.h> /* for ULONG_MAX */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+https://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #include "mpfr-test.h"
 
+#ifndef MPFR_USE_MINI_GMP
+
 int
 main (void)
 {
   mpfr_t x, u;
   mpf_t y, z;
-  mp_exp_t emax;
+  mpfr_exp_t emax;
   unsigned long k, pr;
   int r, inexact;
 
@@ -43,12 +41,12 @@ main (void)
   mpf_set_d (y, 0.0);
 
   /* check prototype of mpfr_init_set_f */
-  mpfr_init_set_f (x, y, GMP_RNDN);
+  mpfr_init_set_f (x, y, MPFR_RNDN);
   mpfr_set_prec (x, 100);
-  mpfr_set_f (x, y, GMP_RNDN);
+  mpfr_set_f (x, y, MPFR_RNDN);
 
   mpf_urandomb (y, RANDS, 10 * GMP_NUMB_BITS);
-  mpfr_set_f (x, y, (mp_rnd_t) RND_RAND());
+  mpfr_set_f (x, y, RND_RAND ());
 
   /* bug found by Jean-Pierre Merlet */
   mpfr_set_prec (x, 256);
@@ -56,10 +54,10 @@ main (void)
   mpfr_init2 (u, 256);
   mpfr_set_str (u,
                 "7.f10872b020c49ba5e353f7ced916872b020c49ba5e353f7ced916872b020c498@2",
-                16, GMP_RNDN);
+                16, MPFR_RNDN);
   mpf_set_str (y, "2033033E-3", 10); /* avoid 2033.033 which is
                                         locale-sensitive */
-  mpfr_set_f (x, y, GMP_RNDN);
+  mpfr_set_f (x, y, MPFR_RNDN);
   if (mpfr_cmp (x, u))
     {
       printf ("mpfr_set_f failed for y=2033033E-3\n");
@@ -67,8 +65,8 @@ main (void)
     }
   mpf_set_str (y, "-2033033E-3", 10); /* avoid -2033.033 which is
                                          locale-sensitive */
-  mpfr_set_f (x, y, GMP_RNDN);
-  mpfr_neg (u, u, GMP_RNDN);
+  mpfr_set_f (x, y, MPFR_RNDN);
+  mpfr_neg (u, u, MPFR_RNDN);
   if (mpfr_cmp (x, u))
     {
       printf ("mpfr_set_f failed for y=-2033033E-3\n");
@@ -79,7 +77,7 @@ main (void)
   mpf_set_str (y, "1111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111", -2);
   mpf_mul_2exp (y, y, 600);
   mpfr_set_prec (x, 300);
-  mpfr_set_f (x, y, GMP_RNDN);
+  mpfr_set_f (x, y, MPFR_RNDN);
   if (mpfr_check (x) == 0)
     {
       printf ("Error in mpfr_set_f: corrupted result\n");
@@ -94,30 +92,30 @@ main (void)
       pr = 2 + (randlimb () & 255);
       mpf_set_prec (z, pr);
       mpf_urandomb (z, RANDS, z->_mp_prec);
-      mpfr_set_prec (u, ((pr / BITS_PER_MP_LIMB + 1) * BITS_PER_MP_LIMB));
-      mpfr_set_f (u, z, GMP_RNDN);
-      if (mpfr_cmp_f (u , z) != 0)
+      mpfr_set_prec (u, ((pr / GMP_NUMB_BITS + 1) * GMP_NUMB_BITS));
+      mpfr_set_f (u, z, MPFR_RNDN);
+      if (mpfr_cmp_f (u, z) != 0)
         {
           printf ("Error in mpfr_set_f:\n");
           printf ("mpf (precision=%lu)=", pr);
           mpf_out_str (stdout, 16, 0, z);
           printf ("\nmpfr(precision=%lu)=",
-                  ((pr / BITS_PER_MP_LIMB + 1) * BITS_PER_MP_LIMB));
-          mpfr_out_str (stdout, 16, 0, u, GMP_RNDN);
+                  ((pr / GMP_NUMB_BITS + 1) * GMP_NUMB_BITS));
+          mpfr_out_str (stdout, 16, 0, u, MPFR_RNDN);
           putchar ('\n');
           exit (1);
         }
       mpfr_set_prec (x, pr);
-      mpfr_set_f (x, z, GMP_RNDN);
-      mpfr_sub (u, u, x, GMP_RNDN);
-      mpfr_abs (u, u, GMP_RNDN);
+      mpfr_set_f (x, z, MPFR_RNDN);
+      mpfr_sub (u, u, x, MPFR_RNDN);
+      mpfr_abs (u, u, MPFR_RNDN);
       if (mpfr_cmp_ui_2exp (u, 1, -pr - 1) > 0)
         {
           printf ("Error in mpfr_set_f: precision=%lu\n", pr);
           printf ("mpf =");
           mpf_out_str (stdout, 16, 0, z);
           printf ("\nmpfr=");
-          mpfr_out_str (stdout, 16, 0, x, GMP_RNDN);
+          mpfr_out_str (stdout, 16, 0, x, MPFR_RNDN);
           putchar ('\n');
           exit (1);
         }
@@ -127,18 +125,18 @@ main (void)
   mpfr_set_prec (x, 53);
   mpf_set_prec (y, 53);
   mpf_set_ui (y, 0);
-  for (r = 0 ; r < GMP_RND_MAX ; r++)
+  RND_LOOP (r)
     {
       int i;
       for (i = -1; i <= 1; i++)
         {
           if (i)
-            mpfr_set_si (x, i, GMP_RNDN);
-          inexact = mpfr_set_f (x, y, (mp_rnd_t) r);
+            mpfr_set_si (x, i, MPFR_RNDN);
+          inexact = mpfr_set_f (x, y, (mpfr_rnd_t) r);
           if (!MPFR_IS_ZERO(x) || !MPFR_IS_POS(x) || inexact)
             {
               printf ("mpfr_set_f(x,0) failed for %s, i = %d\n",
-                      mpfr_print_rnd_mode ((mp_rnd_t) r), i);
+                      mpfr_print_rnd_mode ((mpfr_rnd_t) r), i);
               exit (1);
             }
         }
@@ -150,20 +148,20 @@ main (void)
   mpf_set_ui (y, 1);
   for (r = 0; r < mp_bits_per_limb; r++)
     {
-      mpfr_random (x); /* to fill low limbs with random data */
-      inexact = mpfr_set_f (x, y, GMP_RNDN);
+      mpfr_urandomb (x, RANDS); /* to fill low limbs with random data */
+      inexact = mpfr_set_f (x, y, MPFR_RNDN);
       MPFR_ASSERTN(inexact == 0 && mpfr_cmp_ui_2exp (x, 1, r) == 0);
       mpf_mul_2exp (y, y, 1);
     }
 
   mpf_set_ui (y, 1);
   mpf_mul_2exp (y, y, ULONG_MAX);
-  mpfr_set_f (x, y, GMP_RNDN);
-  mpfr_set_ui (u, 1, GMP_RNDN);
-  mpfr_mul_2ui (u, u, ULONG_MAX, GMP_RNDN);
+  mpfr_set_f (x, y, MPFR_RNDN);
+  mpfr_set_ui (u, 1, MPFR_RNDN);
+  mpfr_mul_2ui (u, u, ULONG_MAX, MPFR_RNDN);
   if (!mpfr_equal_p (x, u))
     {
-      printf ("Error: mpfr_set_f (x, y, GMP_RNDN) for y = 2^ULONG_MAX\n");
+      printf ("Error: mpfr_set_f (x, y, MPFR_RNDN) for y = 2^ULONG_MAX\n");
       exit (1);
     }
 
@@ -174,11 +172,11 @@ main (void)
     {
       mpf_set_ui (y, 1);
       mpf_mul_2exp (y, y, emax);
-      mpfr_set_f (x, y, GMP_RNDN);
-      mpfr_set_ui_2exp (u, 1, emax, GMP_RNDN);
+      mpfr_set_f (x, y, MPFR_RNDN);
+      mpfr_set_ui_2exp (u, 1, emax, MPFR_RNDN);
       if (!mpfr_equal_p (x, u))
         {
-          printf ("Error: mpfr_set_f (x, y, GMP_RNDN) for y = 2^emax\n");
+          printf ("Error: mpfr_set_f (x, y, MPFR_RNDN) for y = 2^emax\n");
           exit (1);
         }
     }
@@ -188,11 +186,11 @@ main (void)
     {
       mpf_set_ui (y, 1);
       mpf_mul_2exp (y, y, emax - 1);
-      mpfr_set_f (x, y, GMP_RNDN);
-      mpfr_set_ui_2exp (u, 1, emax - 1, GMP_RNDN);
+      mpfr_set_f (x, y, MPFR_RNDN);
+      mpfr_set_ui_2exp (u, 1, emax - 1, MPFR_RNDN);
       if (!mpfr_equal_p (x, u))
         {
-          printf ("Error: mpfr_set_f (x, y, GMP_RNDN) for y = 2^(emax-1)\n");
+          printf ("Error: mpfr_set_f (x, y, MPFR_RNDN) for y = 2^(emax-1)\n");
           exit (1);
         }
     }
@@ -205,3 +203,13 @@ main (void)
   tests_end_mpfr ();
   return 0;
 }
+
+#else
+
+int
+main (void)
+{
+  return 77;
+}
+
+#endif
